@@ -947,7 +947,7 @@ class Minio(object):
             for obj in objects:
                 yield obj
 
-    def list_objects_v2(self, bucket_name, prefix='', recursive=False):
+    def list_objects_v2(self, bucket_name, prefix='', recursive=False, start_after=''):
         """
         List objects in the given bucket using the List objects V2 API.
 
@@ -979,6 +979,13 @@ class Minio(object):
             # hello/world/1
             # hello/world/2
 
+
+            objects = minio.list_objects_v2('foo', recursive=True,
+                                          start_after='hello/world/1')
+            for current_object in objects:
+                print(current_object)
+            # hello/world/2
+
         :param bucket_name: Bucket to list objects from
         :param prefix: String specifying objects returned must begin with
         :param recursive: If yes, returns all objects for a specified prefix
@@ -990,9 +997,13 @@ class Minio(object):
         if prefix is None:
             prefix = ''
 
+        if start_after is None:
+            start_after = ''
+
         # Initialize query parameters.
         query = {
             'list-type': '2',
+            'start-after': start_after,
             'prefix': prefix
         }
 
