@@ -437,6 +437,9 @@ def is_valid_bucket_notification_config(notifications):
     ])
 
     NOTIFICATION_EVENTS = set([
+        's3:ObjectAccessed:*',
+        's3:ObjectAccessed:Get',
+        's3:ObjectAccessed:Head',
         's3:ReducedRedundancyLostObject',
         's3:ObjectCreated:*',
         's3:ObjectCreated:Put',
