@@ -27,3 +27,6 @@ class GetS3Endpoint(TestCase):
     def test_is_valid_endpoint(self):
         eq_(True, is_valid_endpoint('s3.amazonaws.com'))
         eq_(True, is_valid_endpoint('s3.cn-north-1.amazonaws.com.cn'))
+        eq_(True, is_valid_endpoint('minio_server:9000'))
+        eq_(True, is_valid_endpoint('s3.server_1.amazonaws.com'))
+        
